@@ -108,6 +108,9 @@ class diamond:
                 % self.faa
             )
             return 0
+        except Exception as e:
+            print(e)
+            return 0
 
         keys = faa.keys()
         if len(keys) > n:
@@ -187,6 +190,9 @@ class multidiamond(diamond):
                 % fasta
             )
             return 0
+        except Exception as e:
+            print(e)
+            return 0
 
         keys = faa.keys()
         if len(keys) > n:
